<?php
namespace Element_Ready\Widgets\scroll_button;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Modules\DynamicTags\Module as TagsModule;
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Repeater;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Element_Ready_Scroll_Button extends Widget_Base {

	public function get_name() {
		return 'Element_Ready_Scroll_Button';
	}

	public function get_title() {
		return esc_html__( 'ER Scroll Top Bottom', 'element-ready-lite' );
	}

	public function get_icon() {
		return 'eicon-import-export';
	}

	public function get_categories() {
		return array('element-ready-addons');
	}

    public function get_keywords() {
        return [ 'Scroll Top', 'Scroll Button', 'Button', 'Scroll Bottom', 'Scroll Up' ];
    }

    public function get_script_depends() {
        return [
            'element-ready-core',
        ];
    }

	protected function register_controls() {

		/******************************
		 * 	CONTENT SECTION
		 ******************************/
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'element-ready-lite' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
			$this->add_control(
				'title',
				[
					'label'       => esc_html__( 'Title', 'element-ready-lite' ),
					'type'        => Controls_Manager::TEXT,
					'placeholder' => esc_html__( 'Title', 'element-ready-lite' ),
				]
			);
			$this->add_control(
				'scroll_type',
				[
					'label'   => esc_html__( 'Scrolling Type', 'element-ready-lite' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'scroll_top',
					'options' => [
						'scroll_top'  => esc_html__( 'Scroll To Top', 'element-ready-lite' ),
						'scroll_bottom' => esc_html__( 'Scroll Bottom Section', 'element-ready-lite' ),
					],
				]
			);
			$this->add_control(
				'button_anchor_id',
				[
					'label'         => esc_html__( 'Scroll Area / Section Id', 'element-ready-lite' ),
					'type'          => Controls_Manager::TEXT,
					'placeholder'   => esc_html__( 'Scroll Section Id', 'element-ready-lite' ),
					'default'       => 'service',
					'condition' => [
						'scroll_type' => 'scroll_bottom',
					],
				]
			);
			$this->add_control(
				'show_icon',
				[
					'label'        => esc_html__( 'Show Icon ?', 'element-ready-lite' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => esc_html__( 'Show', 'element-ready-lite' ),
					'label_off'    => esc_html__( 'Hide', 'element-ready-lite' ),
					'return_value' => 'yes',
					'default'      => 'no',
				]
			);
			$this->add_control(
				'scroll_icon',
				[
					'label'       => esc_html__( 'Chose Icon', 'element-ready-lite' ),
					'type'        => Controls_Manager::ICONS,
					'label_block' => true,
					'condition'   => [
						'show_icon' => 'yes',
					],
				]
			);
			$this->add_control(
				'button_icon_align',
				[
					'label'   => esc_html__( 'Icon Position', 'element-ready-lite' ),
					'type'    => Controls_Manager::SELECT,
					'default' => 'left',
					'options' => [
						'left'  => esc_html__( 'Before', 'element-ready-lite' ),
						'right' => esc_html__( 'After', 'element-ready-lite' ),
					],
					'condition' => [
						'show_icon' => 'yes',
					],
				]
			);
			$this->add_control(
				'button_icon_indent',
				[
					'label' => esc_html__( 'Icon Spacing', 'element-ready-lite' ),
					'type'  => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 50,
						],
					],
					'condition' => [
						'show_icon' => 'yes',
					],
					'selectors' => [
						'{{WRAPPER}} .element__ready__scroll__button .element__ready__scroll__button_icon_right' => 'margin-left: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} .element__ready__scroll__button .element__ready__scroll__button_icon_left'  => 'margin-right: {{SIZE}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
		/*********************************
		 * 		STYLE SECTION
		 *********************************/

		/*----------------------------
			ICON STYLE
		-----------------------------*/
		$this->start_controls_section(
			'icon_style_section',
			[
				'label' => esc_html__( 'Icon', 'element-ready-lite' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
			$this->start_controls_tabs( 'icon_tab_style' );
				$this->start_controls_tab(
					'icon_normal_tab',
					[
						'label' => esc_html__( 'Normal', 'element-ready-lite' ),
					]
				);
					$this->add_group_control(
						Group_Control_Typography:: get_type(),
						[
							'name'      => 'icon_typography',
							'selector'  => '{{WRAPPER}} .button__icon',
						]
					);
					$this->add_responsive_control(
						'icon_image_size',
						[
							'label'      => esc_html__( 'Icon Image Size', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
								'size' => '80',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon svg' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Css_Filter:: get_type(),
						[
							'name'      => 'icon_image_filters',
							'selector'  => '{{WRAPPER}} .button__icon svg',
							'condition' => [
								'scroll_type' => ['image_icon']
							],
						]
					);
					$this->add_control(
						'icon_color',
						[
							'label'     => esc_html__( 'Color', 'element-ready-lite' ),
							'type'      => Controls_Manager::COLOR,
							'default'   => '',
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'color: {{VALUE}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Background:: get_type(),
						[
							'name'     => 'icon_background',
							'label'    => esc_html__( 'Background', 'element-ready-lite' ),
							'types'    => [ 'classic', 'gradient' ],
							'selector' => '{{WRAPPER}} .button__icon',
						]
					);
					$this->add_control(
						'icon_hr2',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_group_control(
						Group_Control_Border:: get_type(),
						[
							'name'     => 'icon_border',
							'label'    => esc_html__( 'Border', 'element-ready-lite' ),
							'selector' => '{{WRAPPER}} .button__icon',
						]
					);
					$this->add_control(
						'icon_radius',
						[
							'label'      => esc_html__( 'Border Radius', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .button__icon' => 'overflow:hidden;border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Box_Shadow:: get_type(),
						[
							'name'     => 'icon_shadow',
							'selector' => '{{WRAPPER}} .button__icon',
						]
					);
					$this->add_control(
						'icon_hr3',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_responsive_control(
						'icon_width',
						[
							'label'      => esc_html__( 'Width', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);
					$this->add_responsive_control(
						'icon_height',
						[
							'label'      => esc_html__( 'Height', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'height: {{SIZE}}{{UNIT}};',
							],
						]
					);
					$this->add_control(
						'icon_hr5',
						[
							'type' => Controls_Manager::DIVIDER
						]
					);
					$this->add_responsive_control(
						'icon_display',
						[
							'label'   => esc_html__( 'Display', 'element-ready-lite' ),
							'type'    => Controls_Manager::SELECT,			
							'options' => [
								'initial'      => esc_html__( 'Initial', 'element-ready-lite' ),
								'block'        => esc_html__( 'Block', 'element-ready-lite' ),
								'inline-block' => esc_html__( 'Inline Block', 'element-ready-lite' ),
								'flex'         => esc_html__( 'Flex', 'element-ready-lite' ),
								'inline-flex'  => esc_html__( 'Inline Flex', 'element-ready-lite' ),
								'none'         => esc_html__( 'None', 'element-ready-lite' ),
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'display: {{VALUE}};',
							],
						]
					);
					$this->add_control(
						'icon_align',
						[
							'label'   => esc_html__( 'Alignment', 'element-ready-lite' ),
							'type'    => Controls_Manager::CHOOSE,
							'options' => [
								'left' => [
									'title' => esc_html__( 'Left', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-left',
								],
								'center' => [
									'title' => esc_html__( 'Center', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-center',
								],
								'right' => [
									'title' => esc_html__( 'Right', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-right',
								],
								'justify' => [
									'title' => esc_html__( 'Justify', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-justify',
								],
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'text-align: {{VALUE}};',
							],
						]
					);
					$this->add_control(
						'icon_hr6',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_responsive_control(
						'icon_position',
						[
							'label'   => esc_html__( 'Position', 'element-ready-lite' ),
							'type'    => Controls_Manager::SELECT,
							'default' => 'initial',
							'options' => [
								'initial'  => esc_html__( 'Initial', 'element-ready-lite' ),
								'absolute' => esc_html__( 'Absulute', 'element-ready-lite' ),
								'relative' => esc_html__( 'Relative', 'element-ready-lite' ),
								'static'   => esc_html__( 'Static', 'element-ready-lite' ),
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'position: {{VALUE}};',
							],
						]
					);
					$this->add_responsive_control(
						'icon_position_from_left',
						[
							'label'      => esc_html__( 'From Left', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'left: {{SIZE}}{{UNIT}};',
							],
							'condition' => [
								'icon_position!' => ['initial','static']
							],
						]
					);
					$this->add_responsive_control(
						'icon_position_from_right',
						[
							'label'      => esc_html__( 'From Right', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'right: {{SIZE}}{{UNIT}};',
							],
							'condition' => [
								'icon_position!' => ['initial','static']
							],
						]
					);
					$this->add_responsive_control(
						'icon_position_from_top',
						[
							'label'      => esc_html__( 'From Top', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'top: {{SIZE}}{{UNIT}};',
							],
							'condition' => [
								'icon_position!' => ['initial','static']
							],
						]
					);
					$this->add_responsive_control(
						'icon_position_from_bottom',
						[
							'label'      => esc_html__( 'From Bottom', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon' => 'bottom: {{SIZE}}{{UNIT}};',
							],
							'condition' => [
								'icon_position!' => ['initial','static']
							],
						]
					);
					$this->add_control(
						'icon_transition',
						[
							'label'      => esc_html__( 'Transition', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px' ],
							'range'      => [
								'px' => [
									'min'  => 0.1,
									'max'  => 3,
									'step' => 0.1,
								],
							],
							'default' => [
								'unit' => 'px',
								'size' => 0.3,
							],
							'selectors' => [
								'{{WRAPPER}} .button__icon,{{WRAPPER}} .button__icon svg' => 'transition: {{SIZE}}s;',
							],
						]
					);
					$this->add_control(
						'icon_hr7',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_responsive_control(
						'icon_margin',
						[
							'label'      => esc_html__( 'Margin', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .button__icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					$this->add_control(
						'icon_hr8',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_responsive_control(
						'icon_padding',
						[
							'label'      => esc_html__( 'Padding', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .button__icon i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
								'{{WRAPPER}} .button__icon svg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
				$this->end_controls_tab();
				$this->start_controls_tab(
					'icon_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'element-ready-lite' ),
					]
				);
					$this->add_group_control(
						Group_Control_Css_Filter:: get_type(),
						[
							'name'      => 'hover_icon_image_filters',
							'selector'  => '{{WRAPPER}} .element__ready__scroll__button:hover .button__icon svg',
							'condition' => [
								'icon_type' => ['image_icon']
							],
						]
					);
					$this->add_control(
						'hover_icon_color',
						[
							'label'     => esc_html__( 'Color', 'element-ready-lite' ),
							'type'      => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .element__ready__scroll__button:hover .button__icon, {{WRAPPER}} :focus .button__icon' => 'color: {{VALUE}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Background:: get_type(),
						[
							'name'     => 'hover_icon_background',
							'label'    => esc_html__( 'Background', 'element-ready-lite' ),
							'types'    => [ 'classic', 'gradient' ],
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover .button__icon,{{WRAPPER}} :focus .button__icon',
						]
					);
					$this->add_control(
						'icon_hr4',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_group_control(
						Group_Control_Border:: get_type(),
						[
							'name'     => 'hover_icon_border',
							'label'    => esc_html__( 'Border', 'element-ready-lite' ),
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover .button__icon,{{WRAPPER}} .element__ready__scroll__button:hover .button__icon',
						]
					);
					$this->add_control(
						'hover_icon_radius',
						[
							'label'      => esc_html__( 'Border Radius', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .element__ready__scroll__button:hover .button__icon' => 'overflow:hidden;border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Box_Shadow:: get_type(),
						[
							'name'     => 'hover_icon_shadow',
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover .button__icon',
						]
					);
				$this->end_controls_tab();
			$this->end_controls_tabs();
		$this->end_controls_section();
		/*----------------------------
			ICON STYLE END
		-----------------------------*/


		/*----------------------------
			TITLE STYLE
		-----------------------------*/
		$this->start_controls_section(
			'title_style_section',
			[
				'label' => esc_html__( 'Title', 'element-ready-lite' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_group_control(
				Group_Control_Typography:: get_type(),
				[
					'name'     => 'title_typography',
					'selector' => '{{WRAPPER}} .button__title',
				]
			);
			$this->add_responsive_control(
				'title_display',
				[
					'label'   => esc_html__( 'Display', 'element-ready-lite' ),
					'type'    => Controls_Manager::SELECT,			
					'options' => [
						'initial'      => esc_html__( 'Initial', 'element-ready-lite' ),
						'block'        => esc_html__( 'Block', 'element-ready-lite' ),
						'inline-block' => esc_html__( 'Inline Block', 'element-ready-lite' ),
						'flex'         => esc_html__( 'Flex', 'element-ready-lite' ),
						'inline-flex'  => esc_html__( 'Inline Flex', 'element-ready-lite' ),
						'none'         => esc_html__( 'None', 'element-ready-lite' ),
					],
					'selectors' => [
						'{{WRAPPER}} .button__title' => 'display: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'title_text_color',
				[
					'label'     => esc_html__( 'Color', 'element-ready-lite' ),
					'type'      => Controls_Manager::COLOR,
					'default'   => '',
					'selectors' => [
						'{{WRAPPER}} .button__title' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_control(
				'box_hover_title_color',
				[
					'label'     => esc_html__( 'Box Hover Color', 'element-ready-lite' ),
					'type'      => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .element__ready__scroll__button:hover .button__title,{{WRAPPER}} .element__ready__scroll__button:focus .button__title' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_responsive_control(
				'title_margin',
				[
					'label'      => esc_html__( 'Margin', 'element-ready-lite' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors'  => [
						'{{WRAPPER}} .button__title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
		/*----------------------------
			TITLE STYLE END
		-----------------------------*/

		/*----------------------------
			BUTTON STYLE
		-----------------------------*/
		$this->start_controls_section(
			'button_style_section',
			[
				'label' => esc_html__( 'Button', 'element-ready-lite' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
			$this->start_controls_tabs( 'button_tab_style' );
				$this->start_controls_tab(
					'button_normal_tab',
					[
						'label' => esc_html__( 'Normal', 'element-ready-lite' ),
					]
				);
					$this->add_group_control(
						Group_Control_Typography:: get_type(),
						[
							'name'     => 'button_typography',
							'selector' => '{{WRAPPER}} .element__ready__scroll__button',
						]
					);
					$this->add_responsive_control(
						'button_display',
						[
							'label'   => esc_html__( 'Display', 'element-ready-lite' ),
							'type'    => Controls_Manager::SELECT,
							'default' => '',
							'options' => [
								'initial'      => esc_html__( 'Initial', 'element-ready-lite' ),
								'block'        => esc_html__( 'Block', 'element-ready-lite' ),
								'inline-block' => esc_html__( 'Inline Block', 'element-ready-lite' ),
								'flex'         => esc_html__( 'Flex', 'element-ready-lite' ),
								'inline-flex'  => esc_html__( 'Inline Flex', 'element-ready-lite' ),
							],
							'selectors' => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'display: {{VALUE}};',
							],
						]
					);
					$this->add_control(
						'button_color',
						[
							'label'     => esc_html__( 'Color', 'element-ready-lite' ),
							'type'      => Controls_Manager::COLOR,
							'default'   => '',
							'selectors' => [
								'{{WRAPPER}} a.element__ready__scroll__button, {{WRAPPER}} .element__ready__scroll__button' => 'color: {{VALUE}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Background:: get_type(),
						[
							'name'     => 'button_background',
							'label'    => esc_html__( 'Background', 'element-ready-lite' ),
							'types'    => [ 'classic', 'gradient' ],
							'selector' => '{{WRAPPER}} .element__ready__scroll__button',
						]
					);
					$this->add_group_control(
						Group_Control_Border:: get_type(),
						[
							'name'     => 'button_border',
							'label'    => esc_html__( 'Border', 'element-ready-lite' ),
							'selector' => '{{WRAPPER}} .element__ready__scroll__button',
						]
					);
					$this->add_control(
						'button_radius',
						[
							'label'      => esc_html__( 'Border Radius', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Box_Shadow:: get_type(),
						[
							'name'     => 'button_shadow',
							'selector' => '{{WRAPPER}} .element__ready__scroll__button',
						]
					);
					$this->add_responsive_control(
						'button_align',
						[
							'label'   => esc_html__( 'Alignment', 'element-ready-lite' ),
							'type'    => Controls_Manager::CHOOSE,
							'options' => [
								'left' => [
									'title' => esc_html__( 'Left', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-left',
								],
								'center' => [
									'title' => esc_html__( 'Center', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-center',
								],
								'right' => [
									'title' => esc_html__( 'Right', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-right',
								],
								'justify' => [
									'title' => esc_html__( 'Justify', 'element-ready-lite' ),
									'icon'  => 'fa fa-align-justify',
								],
							],
							'selectors' => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'text-align: {{VALUE}};',
							],
							'separator' => 'before',
						]
					);
					$this->add_control(
						'button_hr',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_responsive_control(
						'button_width',
						[
							'label'      => esc_html__( 'Width', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'width: {{SIZE}}{{UNIT}};',
							],
						]
					);
					$this->add_responsive_control(
						'button_height',
						[
							'label'      => esc_html__( 'Height', 'element-ready-lite' ),
							'type'       => Controls_Manager::SLIDER,
							'size_units' => [ 'px', '%' ],
							'range'      => [
								'px' => [
									'min'  => 0,
									'max'  => 1000,
									'step' => 1,
								],
								'%' => [
									'min' => 0,
									'max' => 100,
								],
							],
							'default' => [
								'unit' => 'px',
							],
							'selectors' => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'height: {{SIZE}}{{UNIT}};',
							],
						]
					);
					$this->add_control(
						'button_hr2',
						[
							'type' => Controls_Manager::DIVIDER,
						]
					);
					$this->add_responsive_control(
						'button_margin',
						[
							'label'      => esc_html__( 'Margin', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					$this->add_responsive_control(
						'button_padding',
						[
							'label'      => esc_html__( 'Padding', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .element__ready__scroll__button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
				$this->end_controls_tab();
				$this->start_controls_tab(
					'button_hover_tab',
					[
						'label' => esc_html__( 'Hover', 'element-ready-lite' ),
					]
				);
					$this->add_control(
						'hover_button_color',
						[
							'label'     => esc_html__( 'Color', 'element-ready-lite' ),
							'type'      => Controls_Manager::COLOR,
							'selectors' => [
								'{{WRAPPER}} .element__ready__scroll__button:hover, {{WRAPPER}} a.element__ready__scroll__button:focus' => 'color: {{VALUE}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Background:: get_type(),
						[
							'name'     => 'hover_button_background',
							'label'    => esc_html__( 'Background', 'element-ready-lite' ),
							'types'    => [ 'classic', 'gradient' ],
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover,{{WRAPPER}} .element__ready__scroll__button:focus',
						]
					);
					$this->add_control(
						'button_hidding',
						[
							'label'     => esc_html__( 'Button Hover Animated Background', 'element-ready-lite' ),
							'type'      =>Controls_Manager::HEADING,
							'separator' => 'before',
						]
					);
					$this->add_group_control(
						Group_Control_Background:: get_type(),
						[
							'name'     => 'animate_hover_button_background',
							'label'    => esc_html__( 'Background', 'element-ready-lite' ),
							'types'    => [ 'classic', 'gradient' ],
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:before,{{WRAPPER}} .ripple__btn span.repples',
						]
					);
					$this->add_group_control(
						Group_Control_Border:: get_type(),
						[
							'name'     => 'hover_button_border',
							'label'    => esc_html__( 'Border', 'element-ready-lite' ),
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover,{{WRAPPER}} .element__ready__scroll__button:focus',
						]
					);
					$this->add_control(
						'hover_button_radius',
						[
							'label'      => esc_html__( 'Border Radius', 'element-ready-lite' ),
							'type'       => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', '%', 'em' ],
							'selectors'  => [
								'{{WRAPPER}} .element__ready__scroll__button:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
					$this->add_group_control(
						Group_Control_Box_Shadow:: get_type(),
						[
							'name'     => 'hover_button_shadow',
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover',
						]
					);
					$this->add_control(
						'button_hover_animation',
						[
							'label'    => esc_html__( 'Hover Animation', 'element-ready-lite' ),
							'type'     => Controls_Manager::HOVER_ANIMATION,
							'selector' => '{{WRAPPER}} .element__ready__scroll__button:hover',
						]
					);
				$this->end_controls_tab();
			$this->end_controls_tabs();
		$this->end_controls_section();
		/*----------------------------
			BUTTON STYLE END
		-----------------------------*/

		/*----------------------------
			BUTTON WRAP STYLE
		-----------------------------*/
		$this->start_controls_section(
			'button_wrap_style_section',
			[
				'label' => esc_html__( 'Button Wrap', 'element-ready-lite' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_responsive_control(
				'button_wrap_display',
				[
					'label'   => esc_html__( 'Display', 'element-ready-lite' ),
					'type'    => Controls_Manager::SELECT,
					'default' => '',
					'options' => [
						'initial'      => esc_html__( 'Initial', 'element-ready-lite' ),
						'block'        => esc_html__( 'Block', 'element-ready-lite' ),
						'inline-block' => esc_html__( 'Inline Block', 'element-ready-lite' ),
						'flex'         => esc_html__( 'Flex', 'element-ready-lite' ),
						'inline-flex'  => esc_html__( 'Inline Flex', 'element-ready-lite' ),
						'none'         => esc_html__( 'none', 'element-ready-lite' ),
					],
					'selectors' => [
						'{{WRAPPER}}' => 'display: {{VALUE}};',
					],
				]
			);
			$this->add_responsive_control(
				'button_wrap_align',
				[
					'label'   => esc_html__( 'Alignment', 'element-ready-lite' ),
					'type'    => Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => esc_html__( 'Left', 'element-ready-lite' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => esc_html__( 'Center', 'element-ready-lite' ),
							'icon'  => 'fa fa-align-center',
						],
						'right' => [
							'title' => esc_html__( 'Right', 'element-ready-lite' ),
							'icon'  => 'fa fa-align-right',
						],
						'justify' => [
							'title' => esc_html__( 'Justify', 'element-ready-lite' ),
							'icon'  => 'fa fa-align-justify',
						],
					],
					'selectors' => [
						'{{WRAPPER}}' => 'text-align: {{VALUE}};',
					],
					'separator' => 'before',
				]
			);
			$this->add_responsive_control(
				'button_wrap_width',
				[
					'label'      => esc_html__( 'Width', 'element-ready-lite' ),
					'type'       => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range'      => [
						'px' => [
							'min'  => 0,
							'max'  => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}}' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_control(
				'button_wrap_height',
				[
					'label'      => esc_html__( 'Height', 'element-ready-lite' ),
					'type'       => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range'      => [
						'px' => [
							'min'  => 0,
							'max'  => 1000,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
					],
					'selectors' => [
						'{{WRAPPER}}' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'button_wrap_margin',
				[
					'label'      => esc_html__( 'Margin', 'element-ready-lite' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors'  => [
						'{{WRAPPER}}' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'button_wrap_padding',
				[
					'label'      => esc_html__( 'Padding', 'element-ready-lite' ),
					'type'       => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', '%', 'em' ],
					'selectors'  => [
						'{{WRAPPER}}' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
		/*----------------------------
			BUTTON WRAP STYLE END
		-----------------------------*/	
	}
	
	protected function render() {
		$settings = $this->get_settings_for_display();
		$this->add_render_attribute( 'button_style_attr', 'class', 'element__ready__scroll__button' );
		$this->add_render_attribute( 'button_style_attr', 'class', $settings['scroll_type'] );

		$scroll_type = array(
			'scroll_type' => $settings['scroll_type'],
		);
		$this->add_render_attribute( 'button_style_attr', 'data-options', json_encode( $scroll_type ) );


		if ( !empty( $settings['button_anchor_id'] ) ) {
			$this->add_render_attribute( 'button_style_attr', 'href', '#'.$settings['button_anchor_id'] );
		}else{
			$this->add_render_attribute( 'button_style_attr', 'href', '#' );			
		}
		?>
		<?php if ( 'yes' == $settings['show_icon'] && $settings['scroll_icon'] ) : ?>
			<?php if ( $settings['scroll_icon'] ) : ?>
				<?php if (  'left' == $settings['button_icon_align'] ) : ?>
					<a <?php echo $this->get_render_attribute_string('button_style_attr'); ?>>
						<div class="button__icon element__ready__scroll__button_icon_left"><?php Icons_Manager::render_icon( $settings['scroll_icon'] ); ?></div>
						<div class="button__title"><?php echo esc_html( $settings['title'] ) ?></div>
					</a>
				<?php elseif( 'right' == $settings['button_icon_align'] ) : ?>
					<a <?php echo $this->get_render_attribute_string('button_style_attr'); ?>>
						<div class="button__title"><?php echo esc_html( $settings['title'] ) ?></div>
						<div class="button__icon element__ready__scroll__button_icon_right"><?php Icons_Manager::render_icon( $settings['scroll_icon'] ); ?></div>
					</a>
				<?php endif; ?>
			<?php endif; ?>
		<?php else: ?>
			<?php if (  !empty( $settings['title'] ) ) : ?>
				<a <?php echo $this->get_render_attribute_string('button_style_attr'); ?>>
					<div class="button__title"><?php echo esc_html( $settings['title'] ); ?></div>
				</a>
			<?php endif; ?>
		<?php endif; ?>

	<?php
	}
}